@@ -5,7 +5,7 @@ The djapian indexer will help us to make some sense of all this songs...
 
 '''
 from djapian import space, Indexer, CompositeIndexer
-from radioweb.radio.models import *
+from liquidjango.models import *
 
 
 space.add_index(Genre, attach_as='indexer')
