@@ -10,7 +10,7 @@ urlpatterns = patterns('django.contrib.auth.views',
     (r'^logout$', 'logout_then_login'),
                        )     
 
-urlpatterns += patterns('radioweb.radio.views',
+urlpatterns += patterns('liquidjango.views',
     (r'^drop', 'dropbox'),
     (r'^skipcurrent', 'skipcurrent'),
     (r'^audio/(?P<object_id>\d+)/edit$', 'editsong'),
