@@ -120,7 +120,7 @@ def alive():
 
 def play(song):
     '''
-    this function pushes a :model:``radio.models.Song``g in the request playlist 
+    this function pushes a :model:``liquidjango.models.Song``g in the request playlist 
     of the liquidsoap
 
     >>> song =  get_object_or_404(Song, pk=1)
